@@ -21,6 +21,8 @@ pub(crate) struct Match {
     pub spaces: u8,
     /// Stores how many replacements took place while matching.
     pub replacements: u8,
+    /// Stores how many low-confidence replacements took place while matching.
+    pub low_confidence_replacements: u8,
 }
 
 impl Match {
@@ -56,10 +58,15 @@ impl Match {
             self.node.contains_space
         );
 
-        let low_confidence_replacements = !(self.space_before && self.space_after)
+        let too_many_replacements = !(self.space_before && self.space_after)
             && self.node.depth > 1
             && self.spaces.max(self.replacements) as usize + 4 > self.node.depth as usize;
 
+        let low_confidence_replacements = self.low_confidence_replacements > 1
+            && self.low_confidence_replacements as usize
+                > (self.end - self.start).saturating_sub(1)
+            && self.node.depth > 1;
+
         let low_confidence_short = self.replacements >= self.node.depth
             && self.node.depth <= 3
             && !self.node.typ.is(Type::SEVERE);
@@ -67,12 +74,16 @@ impl Match {
         // Make it so "squirrels word" doesn't contain "s word"
         let low_confidence_special = self.node.contains_space && !self.space_before;
 
-        if low_confidence_replacements || low_confidence_short || low_confidence_special {
+        if too_many_replacements
+            || low_confidence_replacements
+            || low_confidence_short
+            || low_confidence_special
+        {
             // Match isn't strong enough.
             #[cfg(feature = "trace")]
             println!(
                 "(rejected: {} {} {})",
-                low_confidence_replacements, low_confidence_short, low_confidence_special
+                too_many_replacements, low_confidence_short, low_confidence_special
             );
             return false;
         }
